autowisp.database.data_model.provenance.telescope module — AutoWISP documentation

# autowisp.database.data_model.provenance.telescope module

## Class Inheritance Diagram

Define the telescope dataset table for the pipeline

class autowisp.database.data_model.provenance.telescope.Telescope(**kwargs)

  Bases: `DataModelBase`

  The table describing the telescopes specified

  __str__()

    Human readable identifier for the telescope.

  id

    A unique identifier for each row.

  notes

    The notes provided for the telescope

  observers
  observing_sessions
  serial_number

    The serial number of the telescope

  telescope_type
  telescope_type_id

    The id of the telescope type

  timestamp

    When record was last changed